# Time Series App

---

A simple application that illustrates basic [time series analysis][ts-wiki] concepts. A [glossary](/glossary) of terms is available to help get started.

You can upload a file, or generate sample data, then interactively fit [ARIMA][arima] models.

In a nutshell, *Time Series Analysis* purposes to learn and emulate the behaviour of data over time. *Time Series Forecasting* then leverages this insight to estimate future values.

![An example of time series analysis results, plotted](/assets/ts.svg)

[ts-wiki]: https://en.wikipedia.org/wiki/Time_series
[arima]: https://en.wikipedia.org/wiki/Autoregressive_integrated_moving_average
